
import os


def file_parsar(path, exclude_files):
    no_file_extension = []
    dicom_files = []
    mhd_files = []
    raw_files = []
    stl_files = []

    for root, dirs, files in os.walk(path):
        if files:
            for name in files:
                filepath = os.path.join(root, name)
                if filepath not in exclude_files:
                    filename, file_extension = os.path.splitext(filepath)

                    if file_extension == '.dcm':
                        dicom_files.append(filepath)

                    elif file_extension == '.mhd':
                        mhd_files.append(filepath)

                    elif file_extension == '.raw':
                        raw_files.append(filepath)

                    elif file_extension == '.stl':
                        stl_files.append(filepath)

                    elif file_extension == '':
                        no_file_extension.append(filepath)

    file_dictionary = {'Dicom': dicom_files,
                       'MHD': mhd_files,
                       'Raw': raw_files,
                       'Stl': stl_files,
                       'NoExtension': no_file_extension}

    return file_dictionary




from setuptools import setup

from src import __version__, __author__

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='MedicalImageConverter',
    author=__author__,
    author_email='csoconnor@mdanderson.org',
    version=__version__,
    description='Reads in medical images and converts them into numpy arrays.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    package_dir={'MedicalImageConverter': 'src'},
    packages=['MedicalImageConverter'],
    include_package_data=True,
    url='https://github.com/caleb-oconnor/MedicalImageConverter',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU Affero General Public License v3"
    ],
    install_requires=['numpy>=1.24.2',
                      'pandas>=2.0.3',
                      'psutil>=5.9.5',
                      'pydicom>=2.4.2',
                      'opencv-python>=4.7.0.72']
)
